@@ -1,21 +1,11 @@
 package Net::DNS::SEC;
 
-use strict;
-use warnings;
-use Carp;
-
-our $SVNVERSION = (qw$Id: SEC.pm 1979 2024-06-02 09:59:31Z willem $)[2];
-our $VERSION;
-$VERSION = '1.24_01';
-
-use base qw(Exporter DynaLoader);
-
-eval { __PACKAGE__->bootstrap($VERSION) };
-warn "\n\n$@\n" if $@;
-
-use Net::DNS 1.08 qw(:DEFAULT);
-
-our @EXPORT = ( @Net::DNS::EXPORT, qw(algorithm digtype key_difference) );
+#
+# $Id: SEC.pm 1380 2015-08-03 06:22:34Z willem $
+#
+use vars qw($VERSION $SVNVERSION);
+$VERSION    = '1.01';
+$SVNVERSION = (qw$LastChangedRevision: 1380 $)[1];
 
 
 =head1 NAME
@@ -28,21 +18,39 @@ Net::DNS::SEC - DNSSEC extensions to Net::DNS
 
 =head1 DESCRIPTION
 
+The Net::DNS::SEC suite provides additional packages required to support
+DNSSEC as described in RFC4033, RFC4034, RFC4035 and subsequent related
+documents.
+
 Net::DNS::SEC is installed as an extension to an existing Net::DNS
-installation providing packages to support DNSSEC as specified in
-RFC4033, RFC4034, RFC4035 and related documents.
+installation.
 
-It also provides support for SIG0 which is useful for dynamic updates.
-
-Implements cryptographic signature generation and verification functions
-using RSA, DSA, ECDSA, and Edwards curve algorithms.
-
-The extended features are made available by replacing Net::DNS by
-Net::DNS::SEC in the use declaration.
+The extended features are made available by substituting Net::DNS::SEC
+for Net::DNS in the use declaration.
 
 =cut
 
 
+use strict;
+use base qw(Exporter);
+
+use Net::DNS 1.01 qw(:DEFAULT);
+
+use vars qw(@EXPORT);
+@EXPORT = ( @Net::DNS::EXPORT, qw(algorithm digtype key_difference) );
+
+
+use integer;
+use warnings;
+use Carp;
+
+eval { require Net::DNS::RR::CDS };
+eval { require Net::DNS::RR::DLV };
+eval { require Net::DNS::RR::DS };
+eval { require Net::DNS::RR::RRSIG };
+eval { require Net::DNS::RR::SIG };
+
+
 =head1 UTILITY FUNCTIONS
 
 =head2 algorithm
@@ -57,7 +65,7 @@ the corresponding mnemonic.
 
 =cut
 
-sub algorithm { return &Net::DNS::RR::DS::algorithm; }
+sub algorithm { &Net::DNS::RR::DS::algorithm; }
 
 
 =head2 digtype
@@ -72,7 +80,7 @@ corresponding mnemonic.
 
 =cut
 
-sub digtype { return &Net::DNS::RR::DS::digtype; }
+sub digtype { &Net::DNS::RR::DS::digtype; }
 
 
 =head2 key_difference
@@ -86,33 +94,33 @@ Fills @result with all keys in array @a that are not in array @b.
 sub key_difference {
 	my $a = shift;
 	my $b = shift;
-	my $r = shift || [];		## 0.17 API
+	my $r = shift || [];		## 0.17 interface
 
-	local $SIG{__DIE__};
-	my ($x) = grep { !$_->isa('Net::DNS::RR::DNSKEY') } @$a, @$b;
-	croak sprintf( 'unexpected %s object in key list', ref $x ) if $x;
+	eval {
+		my ($x) = grep !$_->isa('Net::DNS::RR::DNSKEY'), @$a, @$b;
+		die sprintf 'unexpected %s object in key list', ref($x) if $x;
 
-	my %index = map { ( $_->privatekeyname => 1 ) } @$b;
-	return @$r = grep { !$index{$_->privatekeyname} } @$a;
+		my %index = map { ( $_->privatekeyname => 1 ) } @$b;
+		@$r = grep !$index{$_->privatekeyname}, @$a;
+		1;
+	} || do {
+		croak($@) if wantarray;
+	};
+
+	return wantarray ? (@$r) : $@;
 }
 
 
-########################################
-
-foreach (qw(RRSIG DS CDS)) {
-	Net::DNS::RR->new( type => $_ );			# pre-load to access class methods
-}
-
 1;
 __END__
 
 
 =head1 COPYRIGHT
 
-Copyright (c)2014-2021 Dick Franks
-
 Copyright (c)2001-2005 RIPE NCC. Author Olaf M. Kolkman
 
+Portions Copyright (c)2014-2015 Dick Franks
+
 All Rights Reserved
 
 
@@ -120,7 +128,7 @@ All Rights Reserved
 
 Permission to use, copy, modify, and distribute this software and its
 documentation for any purpose and without fee is hereby granted, provided
-that the original copyright notices appear in all copies and that both
+that the above copyright notice appear in all copies and that both that
 copyright notice and this permission notice appear in supporting
 documentation, and that the name of the author not be used in advertising
 or publicity pertaining to distribution of the software without specific
@@ -137,8 +145,7 @@ DEALINGS IN THE SOFTWARE.
 
 =head1 SEE ALSO
 
-L<perl>, L<Net::DNS>, RFC4033, RFC4034, RFC4035,
-L<OpenSSL|http://www.openssl.org/docs>
+L<perl>, L<Net::DNS>, RFC4033, RFC4034, RFC4035
 
 =cut
 
